Users and Organizations
=======================

.. contents:: :local:

--------------

User
----

* :class:`cfxdb.user.User`
* :class:`cfxdb.globalschema.Users`
* :class:`cfxdb.globalschema.IndexUsersByName`
* :class:`cfxdb.globalschema.IndexUsersByPubkey`
* :class:`cfxdb.globalschema.IndexUsersByEmail`
* :class:`cfxdb.user.UserMrealmRole`
* :class:`cfxdb.globalschema.UserMrealmRoles`
* :class:`cfxdb.user.ActivationToken`
* :class:`cfxdb.globalschema.ActivationTokens`
* :class:`cfxdb.globalschema.IndexActivationTokensByAuthidPubkey`

-------

.. autoclass:: cfxdb.user.User
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.Users
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexUsersByName
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexUsersByPubkey
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexUsersByEmail
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.user.UserMrealmRole
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.UserMrealmRoles
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.user.ActivationToken
    :members:

.. autoclass:: cfxdb.globalschema.ActivationTokens
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexActivationTokensByAuthidPubkey
    :members:
    :show-inheritance:


Organization
------------

* :class:`cfxdb.user.Organization`
* :class:`cfxdb.globalschema.Organizations`
* :class:`cfxdb.globalschema.IndexOrganizationsByName`

-------

.. autoclass:: cfxdb.user.Organization
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.Organizations
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexOrganizationsByName
    :members:
    :show-inheritance:
